const http = require('http');
const axios = require('axios');
const config = require('config');
const ms = require('ms');
const getLogger = require('../utils/logger/logger');
const {
    JWR_TOKEN_TENANCY_AUDIENCE, JWT_TOKEN_API_AUTH0_AUDIENCE, CLIENT_ID, CLIENT_SECRET, JWT_TOKEN_AUTH0
} = require('../utils/consts');


const logger = getLogger();

let tenancyServiceToken;
let occmServiceToken;


async function createServiceToken(audience) {
    const { data } = await axios.post(`${JWT_TOKEN_AUTH0}/oauth/token`, {
        audience,
        client_id: CLIENT_ID,
        client_secret: CLIENT_SECRET,
        grant_type: 'client_credentials'
    }, {
        timeout: ms(config.get('timeout')),
        httpAgent: new http.Agent({ keepAlive: true })
    });
    return `${data.token_type} ${data.access_token}`;
}

async function createTenancyServiceToken() {
    tenancyServiceToken = await createServiceToken(JWR_TOKEN_TENANCY_AUDIENCE);
    logger.info('tenancy token received');
    setInterval(() => createTenancyServiceToken(), ms('12h'));
}

async function createOccmServiceToken() {
    occmServiceToken = await createServiceToken(JWT_TOKEN_API_AUTH0_AUDIENCE);
    logger.info('occm token received ');
    setInterval(() => createTenancyServiceToken(), ms('12h'));
}

function getTenancyServiceToken() {
    return tenancyServiceToken;
}

function getOccmServiceToken() {
    return occmServiceToken;
}

module.exports = {
    createTenancyServiceToken, createOccmServiceToken, getTenancyServiceToken, getOccmServiceToken
};
