const AWS = require('aws-sdk');
const { chunk } = require('lodash');
const { SERVICE_REGION, SELLER_ACCESS_KEY, SELLER_SECRET_KEY } = require('../../utils/consts');
const getLogger = require('../../utils/logger/logger');

const logger = getLogger();

function getMarketplaceMetering() {
    return new AWS.MarketplaceMetering({ region: SERVICE_REGION, accessKeyId: SELLER_ACCESS_KEY, secretAccessKey: SELLER_SECRET_KEY });
}

async function batchMeterUsage(records) {
    const marketplaceMetering = getMarketplaceMetering();

    return Promise.all(chunk(records, 25).map(chunky => {
        const batch = {
            ProductCode: SERVICE_REGION,
            UsageRecords: chunky
        };
        logger.info('Metering request with batch:', batch);

        return marketplaceMetering.batchMeterUsage(batch);
    }));
}

async function resolveCustomerToken(token) {
    const marketplaceMetering = getMarketplaceMetering();
    return marketplaceMetering.resolveCustomer({ RegistrationToken: token }).promise();
}


module.exports = { batchMeterUsage, resolveCustomerToken };
