const axios = require('axios');
const http = require('http');
const ms = require('ms');
const config = require('config');
const { IPA_BASE_URL, IPA_SIGN_PATH } = require('../utils/consts');
const { validateResponse, validateRequest } = require('../utils/schema-validation');
const signLicenseRequestSchema = require('../joi-schemas/ipa-schemas');
const { licenseSchema } = require('../joi-schemas/cloud-manager-schamas');
const getLogger = require('../utils/logger/logger');
const { SIGNED_SERVICE_USER_NAME, SIGNED_SERVICE_PASSWORD } = require('../utils/consts');

const logger = getLogger();

async function signLicense(license) {
    validateRequest(license, signLicenseRequestSchema);
    const { data } = await axios.post(`${IPA_BASE_URL}${IPA_SIGN_PATH}`, license, {
        auth: {
            username: SIGNED_SERVICE_USER_NAME,
            password: SIGNED_SERVICE_PASSWORD
        }
    }, {
        timeout: ms(config.get('timeout')),
        httpAgent: new http.Agent({ keepAlive: true })
    });
    logger.info('Got signed license:', data);
    validateResponse(data, licenseSchema);
    return data;
}

module.exports = signLicense;
