const { ApolloError } = require('apollo-server');
const { AWS, AZURE, CLOUD_TIERING_NAMESPACE } = require('../utils/consts');
const { getAwsRegionByRegionCode, getAwsRegions } = require('../lib/aws/ec2');
const { getAzureRegionByRegionCode } = require('../lib/azure/locations');
const { getAgentIdByClusterId } = require('../operations/multi-tenancy-operation');
const { getAzureRegions } = require('../operations/cloud-manager-operations');

const getLogger = require('../utils/logger/logger');

const logger = getLogger();

async function getRegions(provider, regionCode, clusterId) {
    switch (provider) {
        case AWS: {
            if (regionCode) {
                logger.info(`Get region of provider ${provider} and regionCode ${regionCode}`);
                return [getAwsRegionByRegionCode(regionCode)];
            }
            logger.info(`Get regions to provider ${provider} `);
            return getAwsRegions();
        }
        case AZURE: {
            if (regionCode) {
                return [getAzureRegionByRegionCode(regionCode)];
            }
            if (!clusterId) {
                throw new ApolloError(`${provider} cloud provider requires clusterId`);
            }
            const agentIdByCluster = await getAgentIdByClusterId(clusterId, CLOUD_TIERING_NAMESPACE.get('accountId'));
            return getAzureRegions(agentIdByCluster);
        }
        default: {
            throw new ApolloError(`${provider} cloud provider is not supported`, 400);
        }
    }
}

module.exports = getRegions;
