const express = require('express');
const { getNamespace } = require('cls-hooked');
const Account = require('../models/account');
const { getAccounts } = require('../lib/cloud-manager/multi-tenancy');
const { findAccount } = require('../operations/multi-tenancy-operation');
const { findTieringStats } = require('../operations/cloud-manager-operations');
const { NAME_SPACE_NAME } = require('../utils/consts');
const getLogger = require('../utils/logger/logger');

const logger = getLogger();

const statisticsRoute = express.Router();

statisticsRoute.get('/statistics/account-exists', async (req, res, next) => {
    try {
        const accounts = await getAccounts();
        const accountIds = accounts.map(account => account.accountPublicId);
        logger.info(`Checking if one of the following accounts exist: ${JSON.stringify(accountIds)}`);
        const localAccount = await Account.findOne({ accountId: { $in: accountIds } }).exec();
        res.json(Boolean(localAccount));
    } catch (err) {
        next(err);
    }
});

statisticsRoute.get('/statistics', async (req, res, next) => {
    try {
        const accountId = await findAccount();
        getNamespace(NAME_SPACE_NAME).set('accountId', accountId);
        const stats = await findTieringStats(accountId);
        res.json(stats);
    } catch (err) {
        next(err);
    }
});


module.exports = statisticsRoute;
