const { createNamespace } = require('cls-hooked');
const config = require('config');

const SERVICE_REGION = 'us-east-1';

const MP_PRODUCT_CODE_METERING = 'PRODUCT_CODE';
const SELLER_SECRET_KEY = 'SECRET_KEY';
const SELLER_ACCESS_KEY = 'ACCESS_KEY';
const MP_SUBSCRIPTION_STATUS_SNS_TOPIC = 'SNS_TOPIC';

const AGENDA_PROCESS_EVERY = '10 seconds';
const AGENDA_JOB_NAME_SAAS_METERING = 'MARKETPLACE_METERING';

const SAAS_REGISTRATION_STATUS_UNSUBSCRIBED_INIT = 'unsubscribed-init';
const SAAS_REGISTRATION_STATUS_RESOLVE_FAILED = 'resolve-failed';
const SAAS_REGISTRATION_STATUS_SUBSCRIBE_SUCCESS = 'subscribe-success';
const SAAS_REGISTRATION_STATUS_UNSUBSCRIBE_SUCCESS = 'unsubscribe-success';

const DB_CONNECTION_STRING = process.env.DB_CONNECTION_STRING || config.get('db-connection-string');

// Endpoints
const MULTI_TENANCY_ENDPOINT = process.env.MULTI_TENANCY_ENDPOINT ? `http://${process.env.MULTI_TENANCY_ENDPOINT}` : config.get('services-urls.tenancy');
const AGENTS_MGMT_ENDPOINT = process.env.AGENTS_MGMT_ENDPOINT ? `http://${process.env.AGENTS_MGMT_ENDPOINT}` : config.get('services-urls.agents');
const CLOUD_MANAGER_ENDPOINT = process.env.CLOUD_MANAGER_ENDPOINT ? `http://${process.env.CLOUD_MANAGER_ENDPOINT}` : config.get('services-urls.occm');

const DISCOVER_LOCATION = 'CLOUD_TIERING';
const CLOUD_MANAGER_API_PREFIX = '/occm/api';
const CLOUD_MANAGER_CLUSTERS_PATH_PREFIX = '/onprem/working-environments';
const CLOUD_MANAGER_CLUSTER_METADATA_PATH_PREFIX = '/onprem/metadata/cluster-info';
const CLOUD_MANAGER_AGGREGATES_PATH_PREFIX = '/onprem/aggregates';
const CLOUD_MANAGER_VOLUMES_PATH_PREFIX = '/onprem/volumes';
const CLOUD_MANAGER_OBJECT_STORE_PATH_PREFIX = '/onprem/object-store';
const CLOUD_MANAGER_AZURE_METADATA_REGIONS = '/azure/vsa/metadata/regions';
const CLOUD_MANAGER_AZURE_METADATA_SUBSCRIPTIONS = '/azure/vsa/metadata/associated-subscriptions';
const CLOUD_MANAGER_OBJECT_STORE_CONFIG_PATH_PREFIX = `${CLOUD_MANAGER_OBJECT_STORE_PATH_PREFIX}/config`;
const CLOUD_MANAGER_AGGREGATE_ATTACH_PATH_PREFIX = `${CLOUD_MANAGER_AGGREGATES_PATH_PREFIX}/object-store-attach`;
const CLOUD_MANAGER_FABRIC_POOL_LICENSE_PATH_SUFFIX = 'fabric-pool-license';
const CLOUD_MANAGER_INACTIVE_DATA_REPORTING_PATH_SUFFIX = 'enable-cold-data-reporting';
const CLOUD_MANAGER_CONFIGURE_FP_RESOURCES_PATH_SUFFIX = 'fabric-pool-configure';
const CLOUD_MANAGER_CONFIGURE_AZURE_FP_RESOURCES_PATH_SUFFIX = 'azure-fabric-pool-configure';

const OCCM_BASE_URL = `${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}`;

const JWT_TOKEN_AUTH0 = config.get('auth0-url');
const JWT_TOKEN_API_AUTH0_AUDIENCE = 'https://cloudmanager.cloud.netapp.com';
const JWR_TOKEN_TENANCY_AUDIENCE = 'https://api.cloud.netapp.com';
const CLIENT_ID = process.env.CLIENT_ID || config.get('client_id');
const CLIENT_SECRET = process.env.CLIENT_SECRET || config.get('client_secret');


const IPA_BASE_URL = 'https://support.netapp.com/ServiceGW';
const IPA_SIGN_PATH = '/signMessage';

const SIGNED_SERVICE_USER_NAME = process.env.SIGNED_SERVICE_USER_NAME || config.get('signed_service_user_name');
const SIGNED_SERVICE_PASSWORD = process.env.SIGNED_SERVICE_PASSWORD || config.get('signed_service_password');
const NAME_SPACE_NAME = 'cloudTiering';
const CLOUD_TIERING_NAMESPACE = createNamespace(NAME_SPACE_NAME);// each application wanting to use continuation-local values should create its own namespace

const API_ROOT = '/api';
const GRAPHQL_ROOT = '/graphql';
const API_PATH_VOLUMES = '/volumes';
const API_PATH_TENANTS = '/tenants';
const API_PATH_CLUSTERS = '/clusters';
const API_PATH_ACCOUNTS = '/tenancy/external/account';
const API_PATH_AGENTS = '/agents-mgmt/external/agent';
const API_PATH_RESOURCES = '/tenancy/external/resource';
const API_PATH_RESOURCES_INTERNAL = '/tenancy/internal/resource';
const API_PATH_SAAS_REGISTRATION = '/saas-registration';
const API_PATH_HEALTH = '/health';

const SKIP_AUTHENTICATION_REQUESTS_PATH = [
    API_PATH_SAAS_REGISTRATION, API_PATH_HEALTH
];

const SAVING_OPPORTUNITY_ESTIMATION_RATIO = 0.7;


const SOFT_RESTRICTION = 'soft';
const HARD_RESTRICTION = 'hard';

const AWS = 'AWS';
const AZURE = 'AZURE';
const cloudProviders = {
    AZURE: 'azure',
    AWS: 'aws'
};

const SNAPSHOT_ONLY = 'snapshot_only';
const AUTO = 'auto';
const NONE = 'none';

const storageClasses = {
    ia: 'Standard-Infrequent Access', // from occm to UI
    standard_ia: 'ia', // from tiering to occm
    normal: 'Standard', // from occm to UI
    standard: 'normal', // from tiering to occm,
    hot: 'hot'
};

module.exports = {
    SERVICE_REGION,
    MP_PRODUCT_CODE_METERING,
    MP_SUBSCRIPTION_STATUS_SNS_TOPIC,
    SELLER_SECRET_KEY,
    SELLER_ACCESS_KEY,
    SAAS_REGISTRATION_STATUS_UNSUBSCRIBED_INIT,
    SAAS_REGISTRATION_STATUS_RESOLVE_FAILED,
    SAAS_REGISTRATION_STATUS_SUBSCRIBE_SUCCESS,
    SAAS_REGISTRATION_STATUS_UNSUBSCRIBE_SUCCESS,
    MULTI_TENANCY_ENDPOINT,
    CLOUD_MANAGER_ENDPOINT,
    CLOUD_MANAGER_CLUSTERS_PATH_PREFIX,
    CLOUD_MANAGER_CLUSTER_METADATA_PATH_PREFIX,
    API_ROOT,
    API_PATH_VOLUMES,
    API_PATH_CLUSTERS,
    API_PATH_TENANTS,
    API_PATH_SAAS_REGISTRATION,
    API_PATH_RESOURCES,
    API_PATH_RESOURCES_INTERNAL,
    IPA_SIGN_PATH,
    SKIP_AUTHENTICATION_REQUESTS_PATH,
    JWT_TOKEN_API_AUTH0_AUDIENCE,
    API_PATH_ACCOUNTS,
    CLOUD_MANAGER_AGGREGATES_PATH_PREFIX,
    CLOUD_MANAGER_VOLUMES_PATH_PREFIX,
    CLOUD_MANAGER_FABRIC_POOL_LICENSE_PATH_SUFFIX,
    CLOUD_MANAGER_INACTIVE_DATA_REPORTING_PATH_SUFFIX,
    CLOUD_MANAGER_OBJECT_STORE_CONFIG_PATH_PREFIX,
    CLOUD_MANAGER_AGGREGATE_ATTACH_PATH_PREFIX,
    IPA_BASE_URL,
    API_PATH_AGENTS,
    CLOUD_MANAGER_API_PREFIX,
    AGENDA_PROCESS_EVERY,
    AGENDA_JOB_NAME_SAAS_METERING,
    SOFT_RESTRICTION,
    HARD_RESTRICTION,
    CLOUD_MANAGER_CONFIGURE_FP_RESOURCES_PATH_SUFFIX,
    AGENTS_MGMT_ENDPOINT,
    GRAPHQL_ROOT,
    DISCOVER_LOCATION,
    DB_CONNECTION_STRING,
    API_PATH_HEALTH,
    SAVING_OPPORTUNITY_ESTIMATION_RATIO,
    JWR_TOKEN_TENANCY_AUDIENCE,
    CLIENT_ID,
    CLIENT_SECRET,
    JWT_TOKEN_AUTH0,
    SIGNED_SERVICE_USER_NAME,
    SIGNED_SERVICE_PASSWORD,
    NAME_SPACE_NAME,
    CLOUD_TIERING_NAMESPACE,
    OCCM_BASE_URL,
    CLOUD_MANAGER_AZURE_METADATA_REGIONS,
    CLOUD_MANAGER_AZURE_METADATA_SUBSCRIPTIONS,
    CLOUD_MANAGER_CONFIGURE_AZURE_FP_RESOURCES_PATH_SUFFIX,
    storageClasses,
    cloudProviders,
    SNAPSHOT_ONLY,
    AUTO,
    NONE,
    AWS,
    AZURE
};
