const log4js = require('log4js');
const config = require('config');
const stackTrace = require('stack-trace');
const path = require('path');
const { readFileSync } = require('fs');
const { CLOUD_TIERING_NAMESPACE } = require('../consts');

function configureLayoutWithToken() {
    const configFileContent = JSON.parse(readFileSync(config.get('paths.log4js-config-file')));
    Object.keys(configFileContent.appenders).forEach(appenderType => {
        const { layout } = configFileContent.appenders[appenderType];
        if (layout) {
            const { pattern } = layout;
            if (pattern) {
                layout.tokens = {
                    requestId: () => CLOUD_TIERING_NAMESPACE.get('requestId') || 'system',
                    accountId: () => CLOUD_TIERING_NAMESPACE.get('accountId') || 'system',
                    userName: () => CLOUD_TIERING_NAMESPACE.get('userName') || 'unknown'
                };
            }
        }
    });

    log4js.configure(configFileContent);
}

configureLayoutWithToken();


function getLogger(category = 'server') {
    const logger = log4js.getLogger(category);
    const trace = stackTrace.parse(new Error('something went wrong'));
    logger.addContext('module', trace[1].getFileName().replace(/(^.*[\\/]src[\\/])|(^.*[\\/]cloudtiering[\\/])/, '').split(path.sep).join('.'));
    return logger;
}

module.exports = getLogger;
