const mongoose = require('mongoose');
const Account = require('../../src/models/account');
const getLogger = require('../../src/utils/logger/logger');
const { DB_CONNECTION_STRING } = require('../../src/utils/consts');

const logger = getLogger();
const accountId = '1';
const name = 'test';
const customerIdentifier = '2';
const awsSubscription = { customerIdentifier };

beforeAll(async () => {
    try {
        await mongoose.connect(DB_CONNECTION_STRING, { useNewUrlParser: true, dbName: 'cloudTiering' });
    } catch (e) {
        logger.error('Cannot connect to mongoDB');
    }
});

afterAll(async done => {
    try {
        await mongoose.connection.close();
        done();
    } catch (e) {
        logger.error('Error closing connection', e);
    }
});

describe('Account Model -CRUD', () => {
    beforeEach(() => Account.deleteMany({}));

    test('create', async () => {
        const accountDocument = await Account.create({ name, accountId, awsSubscription });
        expect(accountDocument.accountId).toEqual(accountId);
        expect(accountDocument.awsSubscription.customerIdentifier).toEqual(customerIdentifier);
    });

    test('get', async () => {
        await Account.create({ name, accountId: '2' });
        const foundDoc = await Account.findOne({ accountId: '2' });
        expect(foundDoc.accountId).toEqual('2');
    });

    test('update', async () => {
        await Account.create({ name, accountId });
        await Account.update({ accountId }, { $set: { trialExpiry: 12 } });
        const updatedAccount = Account.findOne({ trialExpiry: 12 });
        expect(updatedAccount).toBeTruthy();
    });

    test('delete', async () => {
        const doc = await Account.create({ name, accountId });
        await doc.remove();
        expect(doc.$isDeleted()).toEqual(true);
    });
});

describe('Account Model -Custom Methods', () => {
    test('toJson', async () => {
        await Account.create({ name, accountId, awsSubscription });
        const result = await Account.findOne({ accountId });
        expect(result.accountId).toEqual(accountId);
        expect(result.awsSubscription.status).toEqual('unsubscribed-init');
    });
});
