const mongoose = require('mongoose');
const getLogger = require('../../src/utils/logger/logger');
const { DB_CONNECTION_STRING } = require('../../src/utils/consts');

const logger = getLogger();
const Metering = require('../../src/models/metering');

beforeAll(async () => {
    try {
        await mongoose.connect(DB_CONNECTION_STRING, { useNewUrlParser: true, dbName: 'cloudTiering' });
    } catch (e) {
        logger.error('Cannot connect to mongoDB');
    }
});

afterAll(async done => {
    try {
        await mongoose.connection.close();
        done();
    } catch (e) {
        logger.error('Error closing connection', e);
    }
});

describe('Metering model -CRUD', () => {
    beforeEach(() => Metering.deleteMany({}));
    const Status = 'succeed';
    const MeteringRecordId = 'record1234';
    const UsageRecord = {
        CustomerIdentifier: 'sagi123',
        Quantity: 5,
        Timestamp: 5325621456
    };
    const meteringObj = { Status, UsageRecord, MeteringRecordId };

    test('get', async () => {
        await Metering.create(meteringObj);
        const foundDoc = await Metering.findOne(meteringObj);
        expect(foundDoc.Status).toEqual(Status);
        expect(foundDoc.MeteringRecordId).toEqual(MeteringRecordId);
        expect(foundDoc.UsageRecord.CustomerIdentifier).toEqual(UsageRecord.CustomerIdentifier);
    });

    test('create', async () => {
        const meteringDocument = await Metering.create(meteringObj);
        expect(meteringDocument.UsageRecord.Quantity).toEqual(UsageRecord.Quantity);
        expect(meteringDocument.UsageRecord.CustomerIdentifier).toEqual(UsageRecord.CustomerIdentifier);
    });

    test('delete', async () => {
        const doc = await Metering.create(meteringObj);
        await doc.remove();
        expect(doc.$isDeleted()).toEqual(true);
    });

    test('update', async () => {
        await Metering.create(meteringObj);
        await Metering.update({ MeteringRecordId }, { $set: { UsageRecord: { Quantity: 6 } } });
        expect(Metering.findOne({ UsageRecord: { Quantity: 6 } })).toBeTruthy();
    });
});
