const bytes = require('bytes');
const { sign, decode } = require('jsonwebtoken');
const { trimStart } = require('lodash');

function escapeForwardSlash(input) {
    return new RegExp(input.replace(/\//g, '\\/'));
}

function convertBytesToCapacity(bytes1) {
    const sizeString = bytes(bytes1);
    const regexPattern = /(\d+\.{0,1}\d*)(\S+)/;
    const match = regexPattern.exec(sizeString);
    if (match) {
        const [, size, unit] = match;
        return { size: parseFloat(size), unit };
    }
    throw new Error(`Failed to parse ${sizeString} to size and unit`);
}


function signJwtToken(user = 'user1') {
    return `Bearer ${sign({ sub: user }, 'secret', { audience: 'https://cloudmanager.cloud.netapp.com', issuer: 'https://staging-netapp-cloud-account.auth0.com' })}`;
}

function findUserId(userToken) {
    const { payload } = decode(trimStart(userToken, 'Bearer').trim(), { complete: true });
    return payload.sub;
}

module.exports = {
    escapeForwardSlash, convertBytesToCapacity, signJwtToken, findUserId
};
